import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { json, geoAlbersUsa, geoPath } from 'd3';
import { feature } from 'topojson';

const countriesUrl = 'https://cdn.freecodecamp.org/testable-projects-fcc/data/choropleth_map/counties.json';
const eduUrl = 'https://cdn.freecodecamp.org/testable-projects-fcc/data/choropleth_map/for_user_education.json';
var projection = geoAlbersUsa();
var path = geoPath(projection);

const width = 900;
const height = 500;
const margin = { top: 50, bottom: 65, right: 40, left: 40 };

const App = () => {
 	const [countries, setCountries] = useState(null);
  const [eduData, setEduData] = useState(null);
  useEffect(() => {
  	json(countriesUrl).then(topojsonData => {
      const { counties } = topojsonData.objects;
      setCountries(feature(topojsonData, counties));
    });
  }, []);
  
  useEffect(() => {
  	json(eduUrl).then(setEduData);
  }, []);
  
  if (!countries || !eduData) {
    return <div>Loading...</div>;
  }
  
  return (
  	<>
    	<svg width={width} height={height}>
      	<g className="marks">
          {
          	countries.features.map(d => <path d={path(feature)} />)
          }
        </g>
      </svg>
    </>
  );
}

ReactDOM.render(<App />, document.getElementById('root'));
